<!DOCTYPE html>
<html lang="en">

<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <meta http-equiv="X-UA-Compatible" content="ie=edge">
  <title>FastAI Model Serving</title>
  <link rel="stylesheet" href="static/css/bootstrap-reboot.min.css">
  <link rel="stylesheet" href="static/css/bootstrap.min.css">
  <script src="static/js/jquery-3.3.1.slim.min.js"></script>
  <script src="static/js/popper.min.js"></script>
  <script src="static/js/bootstrap.min.js"></script>
</head>

<body>
  <div class="container">
    <h2 style="margin: 32px 0; text-align: center;">FastAI Model Predictions</h2>
    <div class="row">
      {% for item in predictions %}
      <div class="col-sm">
        <figure class="figure">
          <img src="data:image/png;base64, {{ item.image }}" class="figure-img img-thumbnail input-image">
          <figcaption class="figure-caption">{{ item.name }} /
            <span class="predicted-label">{{ item.label}}</span>
          </figcaption>
        </figure>
      </div>
      {% endfor %}
    </div>
  </div>


  <style>
    .contiainer {
      padding-top: 32px;
    }

    .input-image {
      min-width: 160px;
    }

    .predicted-label {
      color: black;
      text-align: center;
      font-size: 16px;
      font-weight: bold;
    }
  </style>
</body>

</html>